summaryrefslogtreecommitdiffstats
path: root/src/bookmarkssidebarpage.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/bookmarkssidebarpage.h')
-rw-r--r--src/bookmarkssidebarpage.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/bookmarkssidebarpage.h b/src/bookmarkssidebarpage.h
index 20ef4c9..0e4b962 100644
--- a/src/bookmarkssidebarpage.h
+++ b/src/bookmarkssidebarpage.h
@@ -41,7 +41,7 @@ class BookmarksSidebarPage : public SidebarPage
TQ_OBJECT
public:
- BookmarksSidebarPage(TQWidget* tqparent);
+ BookmarksSidebarPage(TQWidget* parent);
virtual ~BookmarksSidebarPage();
protected:
@@ -71,8 +71,8 @@ private:
/**
* Updates the selection dependent from the given URL \a url. The
* URL must not match exactly to one of the available bookmarks:
* The bookmark which is equal to the URL or at least is a tqparent URL
* is selected. If there are more than one possible tqparent URL candidates,
* the bookmark which covers the bigger range of the URL is selected.
*/
void adjustSelection(const KURL& url);
@@ -98,7 +98,7 @@ class BookmarksListBox : public TQListBox
TQ_OBJECT
public:
- BookmarksListBox(TQWidget* tqparent);
+ BookmarksListBox(TQWidget* parent);
virtual ~BookmarksListBox();
protected:
@@ -71,8 +71,8 @@ private:
* Updates the selection dependent from the given URL \a url. The
* URL must not match exactly to one of the available bookmarks:
- * The bookmark which is equal to the URL or at least is a tqparent URL
- * is selected. If there are more than one possible tqparent URL candidates,
+ * The bookmark which is equal to the URL or at least is a parent URL
+ * is selected. If there are more than one possible parent URL candidates,
* the bookmark which covers the bigger range of the URL is selected.
*/